PyWEED
==========================

PyWEED is a cross-platform downloadable app for retrieving event-based seismic data.

This software is a product of the `IRIS Data Management Center`_.

(For the Weed-FS library previously registered as "pyweed" see https://pypi.org/project/pyseaweed/.)

.. _IRIS Data Management Center: http://ds.iris.edu/
